Resources — django-applepodcast 0.1 documentation

# Resources

Some of the helpful resources used to create the app.

## Documentation

- Django’s syndication feed framework

## Specifications

- RSS 2.0 specification
- Podcasts Connect help (iTunes-specific tags)
- iOS 11 specification update
- Google Play Music
- ID3 standards
- iTunes metadata

## Validators

- W3C Feed Validation Service
- Podba.se Podcast Validator
- Cast Feed Validator
- Feed Validator

## Resources

- iTunes Connect resources
- Podcasts Connect help

## Marketing

- Apple Podcasts Identity Guidelines

## Submission

- iTunes Connect
- Google Play Music Podcast Portal